%define anolis_release 2

%global libname solv

%bcond_without python_bindings
%bcond_without perl_bindings
%bcond_without ruby_bindings
%bcond_without appdata
%bcond_without comps
%bcond_without conda
%bcond_without complex_deps
%bcond_without helix_repo
%bcond_without suse_repo
%bcond_without debian_repo
%bcond_without arch_repo
%bcond_without multi_semantics
%bcond_with zchunk
%bcond_without zstd

%define __cmake_switch(b:) %[%{expand:%%{?with_%{-b*}}} ? "ON" : "OFF"]

Name:           libsolv
Version:        0.7.24
Release:        %{anolis_release}%{?dist}
Summary:        Package dependency solver
License:        BSD
URL:            https://github.com/openSUSE/libsolv
Source:         https://github.com/openSUSE/libsolv/archive/refs/tags/%{version}.tar.gz
Patch0:		libsolv-0.7.24-linkage.patch

BuildRequires:  cmake gcc-c++ ninja-build pkgconfig(rpm) zlib-devel
BuildRequires:  libxml2-devel bzip2-devel xz-devel

%if %{with zchunk}
BuildRequires:  pkgconfig(zck)
%endif
%if %{with zstd}
BuildRequires:  libzstd-devel
%endif

%description
libsolv is a library for solving packages and reading repositories. The solver 
uses a satisfiability algorithm to solve the dependcies.

%package devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}-%{release}
Requires:       pkgconfig(rpm)

%description devel
Development files for %{name}.

%package tools
Summary:        Package dependency solver tools
Requires:       %{name} = %{version}-%{release}
Requires:       findutils

%description tools
Package dependency solver tools.

%if %{with perl_bindings}
%package -n perl-%{libname}
Summary:        Perl bindings for the %{name} library
BuildRequires:  swig perl-devel perl-generators
Requires:       %{name} = %{version}-%{release}

%description -n perl-%{libname}
Perl bindings for the %{name} library.
%endif

%if %{with ruby_bindings}
%package -n ruby-%{libname}
Summary:        Ruby bindings for the %{name} library
BuildRequires:  swig ruby-devel
Requires:       %{name} = %{version}-%{release}

%description -n ruby-%{libname}
Ruby bindings for the %{name} library.
%endif

%if %{with python_bindings}
%package -n python3-%{libname}
Summary:        Python bindings for the %{name} library
%{?python_provide:%python_provide python3-%{libname}}
BuildRequires:  swig python3-devel
Requires:       %{name} = %{version}-%{release}

%description -n python3-%{libname}
Python bindings for the %{name} library.
%endif

%package demo
Summary:        Applications demoing the %{name} library
Requires:       %{name} = %{version}-%{release}
Requires:       curl gnupg2

%description demo
Applications demoing the %{name} library.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -p1

%build
%cmake -GNinja                                            \
  -DFEDORA=1                                              \
  -DENABLE_RPMDB=ON                                       \
  -DENABLE_RPMDB_BYRPMHEADER=ON                           \
  -DENABLE_RPMDB_LIBRPM=ON                                \
  -DENABLE_RPMPKG_LIBRPM=ON                               \
  -DENABLE_RPMMD=ON                                       \
  -DENABLE_COMPS=%{__cmake_switch -b comps}               \
  -DENABLE_APPDATA=%{__cmake_switch -b appdata}           \
  -DUSE_VENDORDIRS=ON                                     \
  -DWITH_LIBXML2=ON                                       \
  -DENABLE_LZMA_COMPRESSION=ON                            \
  -DENABLE_BZIP2_COMPRESSION=ON                           \
  -DENABLE_ZSTD_COMPRESSION=%{__cmake_switch -b zstd}     \
  -DENABLE_ZCHUNK_COMPRESSION=%{__cmake_switch -b zchunk} \
%if %{with zchunk}
  -DWITH_SYSTEM_ZCHUNK=ON                                 \
%endif
  -DENABLE_HELIXREPO=%{__cmake_switch -b helix_repo}      \
  -DENABLE_SUSEREPO=%{__cmake_switch -b suse_repo}        \
  -DENABLE_DEBIAN=%{__cmake_switch -b debian_repo}        \
  -DENABLE_ARCHREPO=%{__cmake_switch -b arch_repo}        \
  -DMULTI_SEMANTICS=%{__cmake_switch -b multi_semantics}  \
  -DENABLE_COMPLEX_DEPS=%{__cmake_switch -b complex_deps} \
  -DENABLE_CONDA=%{__cmake_switch -b conda}               \
  -DENABLE_PERL=%{__cmake_switch -b perl_bindings}        \
  -DENABLE_RUBY=%{__cmake_switch -b ruby_bindings}        \
  -DENABLE_PYTHON=%{__cmake_switch -b python_bindings}    \
%if %{with python_bindings}
  -DPYTHON_EXECUTABLE=%{python3}                          \
%endif
  %{nil}
%cmake_build

%install
%cmake_install

%generate_compatibility_deps

%check
%ctest

export PYTHONPATH=%{buildroot}%{python3_sitearch}
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}
%python3 -c 'import solv'

%files
%dir %{abidir}
%license LICENSE*
%{_libdir}/%{name}.so.*
%{_libdir}/%{name}ext.so.*
%{abidir}/%{name}*.dump
%{abidir}/_solv.dump
%{abidir}/solv.dump

%files devel
%{_libdir}/%{name}.so
%{_libdir}/%{name}ext.so
%{_includedir}/%{libname}/
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/pkgconfig/%{name}ext.pc
%dir %{_datadir}/cmake/Modules/
%{_datadir}/cmake/Modules/FindLibSolv.cmake
%{_mandir}/man3/%{name}*.3*

%files tools
%{_bindir}/deltainfoxml2solv
%{_bindir}/dumpsolv
%{_bindir}/installcheck
%{_bindir}/mergesolv
%{_bindir}/repo2solv
%{_bindir}/repomdxml2solv
%{_bindir}/rpmdb2solv
%{_bindir}/rpmmd2solv
%{_bindir}/rpms2solv
%{_bindir}/testsolv
%{_bindir}/updateinfoxml2solv
%{abidir}/deltainfoxml2solv-option.list
%{abidir}/dumpsolv-option.list
%{abidir}/mergesolv-option.list
%{abidir}/repo2solv-option.list
%{abidir}/repomdxml2solv-option.list
%{abidir}/rpmdb2solv-option.list
%{abidir}/rpmmd2solv-option.list
%{abidir}/testsolv-option.list
%{abidir}/updateinfoxml2solv-option.list
%{_mandir}/man1/deltainfoxml2solv.1.*
%{_mandir}/man1/dumpsolv.1.*
%{_mandir}/man1/installcheck.1.*
%{_mandir}/man1/mergesolv.1.*
%{_mandir}/man1/repo2solv.1.*
%{_mandir}/man1/repomdxml2solv.1.*
%{_mandir}/man1/rpmdb2solv.1.*
%{_mandir}/man1/rpmmd2solv.1.*
%{_mandir}/man1/rpms2solv.1.*
%{_mandir}/man1/testsolv.1.*
%{_mandir}/man1/updateinfoxml2solv.1.*
%if %{with comps}
  %{_bindir}/comps2solv
  %{abidir}/comps2solv-option.list
  %{_mandir}/man1/comps2solv.1.*
%endif
%if %{with appdata}
  %{_bindir}/appdata2solv
  %{abidir}/appdata2solv-option.list
  %{_mandir}/man1/appdata2solv.1.*
%endif
%if %{with debian_repo}
  %{_bindir}/deb2solv
  %{_mandir}/man1/deb2solv.1.*
%endif
%if %{with arch_repo}
  %{_bindir}/archpkgs2solv
  %{_bindir}/archrepo2solv
  %{abidir}/archrepo2solv-option.list
  %{_mandir}/man1/archpkgs2solv.1.*
  %{_mandir}/man1/archrepo2solv.1.*
%endif
%if %{with helix_repo}
  %{_bindir}/helix2solv
  %{_mandir}/man1/helix2solv.1.*
%endif
%if %{with suse_repo}
  %{_bindir}/susetags2solv
  %{abidir}/susetags2solv-option.list
  %{_mandir}/man1/susetags2solv.1.*
%endif
%if %{with conda}
  %{_bindir}/conda2solv
  %{abidir}/conda2solv-option.list
%endif

%if %{with perl_bindings}
%files -n perl-%{libname}
%{perl_vendorarch}/%{libname}.pm
%{perl_vendorarch}/%{libname}.so
%endif

%if %{with ruby_bindings}
%files -n ruby-%{libname}
%{ruby_vendorarchdir}/%{libname}.so
%endif

%if %{with python_bindings}
%files -n python3-%{libname}
%{python3_sitearch}/_%{libname}.so
%{python3_sitearch}/%{libname}.py
%{python3_sitearch}/__pycache__/%{libname}.*
%endif

%files demo
%{_bindir}/solv
%{_mandir}/man1/solv.1.*

%files doc
%doc NEWS README TODO_1.0

%changelog
* Tue Apr 01 2025 Xiaoping Liu <lxp01404969@alibaba-inc.com> - 0.7.24-2
- Rebuild with new ruby

* Tue Mar 26 2024 Funda Wang <fundawang@yeah.net> - 0.7.24-1
- New version 0.7.24

* Tue Mar 12 2024 Bo Ren <rb01097748@alibaba-inc.com> - 0.7.23-3
- Rebuild with python3.11

* Tue Apr 11 2023 yuanhui <yuanhui@linux.alibaba.com> - 0.7.23-2
- Optimize the spec file

* Sun Jan 1 2023 Funda Wang <fundawang@yeah.net> - 0.7.23-1
- New version 0.7.23

* Thu Oct 20 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 0.7.20-3
- optimise spec file

* Tue Mar 22 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 0.7.20-2
- disable zchunk

* Tue Mar 08 2022 pangqing <pangqing@uniontech.com> - 0.7.20-1
- Init for anolisOS 23
